diff --git a/src/main/java/com/seibel/lod/util/LodUtil.java b/src/main/java/com/seibel/lod/util/LodUtil.java
index 726f977ac..6dc9f1e44 100644
--- a/src/main/java/com/seibel/lod/util/LodUtil.java
+++ b/src/main/java/com/seibel/lod/util/LodUtil.java
@@ -52,11 +52,9 @@ public class LodUtil
/**
* In order of nearest to farthest:
* Orange, Yellow, Green, Blue, Magenta, Red
*
* Black is included in index 0, but it shouldn't be used normally.
*/
- public static final Color DEBUG_DETAIL_LEVEL_COLORS[] = new Color[] { Color.BLACK, Color.ORANGE, Color.YELLOW, Color.GREEN, Color.BLUE, Color.MAGENTA, Color.RED};
+ public static final Color DEBUG_DETAIL_LEVEL_COLORS[] = new Color[] { Color.RED, Color.ORANGE, Color.YELLOW, Color.GREEN, Color.BLUE, Color.MAGENTA, Color.pink};
/**
@@ -52,11 +52,9 @@ public class LodUtil
/**
* In order of nearest to farthest:
- * Orange, Yellow, Green, Blue, Magenta, Red
- *
- * Black is included in index 0, but it shouldn't be used normally.
+ * Red, Orange, Yellow, Green, Blue, Magenta, Pink
*/